package
Version:
v0.0.0-...-335459d
Opens a new window with list of versions in this module.
Published: Sep 19, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func InitializeService() error
初始化拖拽服务 - 在程序启动时调用
func SetMainThreadInfo() error
设置主线程信息 - 将当前Go线程信息传递给C++
StartDrag Windows - 使用 CGO 服务直接触发拖拽
Source Files
¶
Click to show internal directories.
Click to hide internal directories.